pub struct ExecError { /* private fields */ }Expand description
An error from failing to execute a command. Produced by CommandExt.
This is a command that fails to start, rather than a command that exits with a non-zero status
or similar, like OutputError.
let mut command = Command::new("echo");
command.arg("puppy doggy");
let displayed: Utf8ProgramAndArgs = (&command).into();
let error = ExecError::new(
Box::new(displayed),
std::io::Error::new(
std::io::ErrorKind::NotFound,
"File not found (os error 2)"
),
);
assert_eq!(
error.to_string(),
"Failed to execute `echo`: File not found (os error 2)"
);Implementations